@@ -1,4 +1,4 @@
-/*  $Id: radius.c,v 1.13.2.1 2000/08/14 22:47:17 kondou Exp $
+/*  $Id: radius.c,v 1.13.2.3 2000/10/01 22:54:07 kondou Exp $
 **
 **  Authenticate a user against a remote radius server.
 */
@@ -180,6 +180,7 @@ int rad_auth(rad_config_t *config, char *uname, char *pass)
     int got;
     fd_set rdfds;
     uint32_t nvalue;
+    ARGTYPE slen;
 
     /* first, build the sockaddrs */
     memset(&sinl, '\0', sizeof(sinl));
@@ -357,9 +358,9 @@ int rad_auth(rad_config_t *config, char *uname, char *pass)
 	    tmout.tv_usec = 0;
 	    continue;
 	}
-	jlen = sizeof(sinl);
+	slen = sizeof(sinl);
 	if ((jlen = recvfrom(sock, (char *)&req, sizeof(req)-sizeof(int), 0, 
-	                     (struct sockaddr*) &sinl, &jlen)) < 0) {
+	                     (struct sockaddr*) &sinl, &slen)) < 0) {
 	    fprintf(stderr, "radius: couldnt recvfrom: %s\n", strerror(errno));
 	    break;
 	}
@@ -422,6 +423,7 @@ int main(int argc, char *argv[])
 
     bzero(&radconfig, sizeof(rad_config_t));
     haveother = havefile = 0;
+    if (ReadInnConf() < 0) exit(1);
 
     while ((opt = getopt(argc, argv, "f:h:p:P:q:s:l:S")) != -1) {
 	switch (opt) {
