@@ -1,144 +1,143 @@
-/*  $Id: ctlinnd.c 10153 2017-06-05 12:28:01Z iulius $
+/*  $Id: ctlinnd.c,v 1.13 2000/04/12 03:06:52 rra Exp $
 **
 **  Send control messages to the InterNetNews daemon.
 */
-
 #include "config.h"
 #include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
 #include <sys/stat.h>
+#include <syslog.h>  
 
-#include "inn/innconf.h"
-#include "inn/messages.h"
-#include "inn/inndcomm.h"
-#include "inn/libinn.h"
-#include "inn/paths.h"
+#include "inndcomm.h"
+#include "libinn.h"
+#include "macros.h"
+#include "paths.h"
 
 
 /*
 **  Datatype for an entry in the command table.
 */
 typedef struct _COMMAND {
-    const char *Command;
-    const char *Text;
+    STRING	Command;
+    STRING	Text;
     int		argc;
     char	Letter;
-    bool	Glue;
+    BOOL	Glue;
 } COMMAND;
 
 
-static COMMAND	Commands[] = {
-    {	"addhist",	"id arr exp post token...\tAdd history line",
-	5,	SC_ADDHIST,	true	},
+STATIC COMMAND	Commands[] = {
+    {	"addhist",	"id arr exp post path...\tAdd history line",
+	5,	SC_ADDHIST,	TRUE	},
     {	"allow",	"reason...\t\t\tAllow remote connections",
-	1,	SC_ALLOW,	true	},
+	1,	SC_ALLOW,	TRUE	},
     {	"begin",	"site\t\t\tStart newly-added site",
-	1,	SC_BEGIN,	false	},
+	1,	SC_BEGIN,	FALSE	},
     {	"cancel",	"id\t\t\tCancel message locally",
-	1,	SC_CANCEL,	false	},
+	1,	SC_CANCEL,	FALSE	},
     {	"changegroup",	"group rest\tChange mode of group",
-	2,	SC_CHANGEGROUP,	false	},
+	2,	SC_CHANGEGROUP,	FALSE	},
     {	"checkfile",	"\t\t\tCheck syntax of newsfeeds file",
-	0,	SC_CHECKFILE,	false	},
+	0,	SC_CHECKFILE,	FALSE	},
     {	"drop",		"site\t\t\tStop feeding site",
-	1,	SC_DROP,	false		},
+	1,	SC_DROP,	FALSE		},
     {	"feedinfo",		"site\t\t\tPrint state of feed to site*",
-	1,	SC_FEEDINFO,	false		},
+	1,	SC_FEEDINFO,	FALSE		},
+#if defined(DO_TCL)
+    {	"tcl",			"flag\t\t\tEnable or disable Tcl filtering",
+	1,	SC_FILTER,	FALSE		},
+#endif /* defined(DO_TCL) */
     {	"flush",	"site\t\t\tFlush feed for site*",
-	1,	SC_FLUSH,	false	},
+	1,	SC_FLUSH,	FALSE	},
     {	"flushlogs",	"\t\t\tFlush log files",
-	0,	SC_FLUSHLOGS,	false	},
+	0,	SC_FLUSHLOGS,	FALSE	},
     {	"go",		"reason...\t\t\tRestart after pause or throttle",
-	1,	SC_GO,		true	},
+	1,	SC_GO,		TRUE	},
     {	"hangup",	"channel\t\tHangup specified incoming channel",
-	1,	SC_HANGUP,	false	},
+	1,	SC_HANGUP,	FALSE	},
     {	"logmode",		"\t\t\t\tSend server mode to syslog",
-	0,	SC_LOGMODE,	false		},
+	0,	SC_LOGMODE,	FALSE		},
     {	"mode",		"\t\t\t\tPrint operating mode",
-	0,	SC_MODE,	false		},
+	0,	SC_MODE,	FALSE		},
     {	"name",		"nnn\t\t\tPrint name of specified channel*",
-	1,	SC_NAME,	false		},
+	1,	SC_NAME,	FALSE		},
     {	"newgroup",	"group rest creator\tCreate new group",
-	3,	SC_NEWGROUP,	false	},
+	3,	SC_NEWGROUP,	FALSE	},
     {	"param",	"letter value\t\tChange command-line parameters",
-	2,	SC_PARAM,	false	},
+	2,	SC_PARAM,	FALSE	},
     {	"pause",	"reason...\t\tShort-term pause in accepting articles",
-	1,	SC_PAUSE,	true	},
-#ifdef DO_PERL
+	1,	SC_PAUSE,	TRUE	},
+#if defined(DO_PERL)
     {	"perl",			"flag\t\t\tEnable or disable Perl filtering",
-	1,	SC_PERL,	false	},
-#endif
-#ifdef DO_PYTHON
+	1,	SC_PERL,	FALSE	},
+#endif /* defined(DO_PERL) */
+#if defined(DO_PYTHON)
     {	"python",		"flag\t\t\tEnable or disable Python filtering",
-	1,	SC_PYTHON,	false	},
-#endif
+	1,	SC_PYTHON,	FALSE	},
+#endif /* (DO_PYTHON) */
     {	"readers",	"flag text...\t\tEnable or disable newsreading",
-	2,	SC_READERS,	true	},
+	2,	SC_READERS,	TRUE	},
     {	"reject",	"reason...\t\t\tReject remote connections",
-	1,	SC_REJECT,	true	},
+	1,	SC_REJECT,	TRUE	},
     {	"reload",	"what reason...\t\tRe-read config files*",
-	2,	SC_RELOAD,	true	},
+	2,	SC_RELOAD,	TRUE	},
     {	"renumber",	"group\t\tRenumber the active file*",
-	1,	SC_RENUMBER,	false	},
+	1,	SC_RENUMBER,	FALSE	},
     {	"reserve",	"reason...\t\tReserve the next pause or throttle",
-	1,	SC_RESERVE,	true	},
+	1,	SC_RESERVE,	TRUE	},
     {	"rmgroup",	"group\t\t\tRemove named group",
-	1,	SC_RMGROUP,	false	},
+	1,	SC_RMGROUP,	FALSE	},
     {	"send",		"feed text...\t\tSend text to exploder feed",
-	2,	SC_SEND,	true	},
+	2,	SC_SEND,	TRUE	},
     {	"shutdown",	"reason...\t\tShut down server",
-	1,	SC_SHUTDOWN,	true	},
-    {	"stathist",	"filename|off\t\tLog into filename some history stats",
-	1,	SC_STATHIST,	false	},
+	1,	SC_SHUTDOWN,	TRUE	},
     {	"status",	"interval|off\t\tTurn innd status generation on or off",
-	1,	SC_STATUS,	false	},
+	1,	SC_STATUS,	FALSE	},
     {	"kill",	"signal site\t\tSend signal to site's process",
-	2,	SC_SIGNAL,	false	},
+	2,	SC_SIGNAL,	FALSE	},
     {	"throttle",	"reason...\t\tStop accepting articles",
-	1,	SC_THROTTLE,	true	},
+	1,	SC_THROTTLE,	TRUE	},
     {   "timer",	"interval|off\t\tTurn performance monitoring on or off",
-	1,	SC_TIMER,	false	},
+	1,	SC_TIMER,	FALSE	},
     {	"trace",	"innd|#|nnrpd flag\tTurn tracing on or off",
-	2,	SC_TRACE,	false	},
+	2,	SC_TRACE,	FALSE	},
     {	"xabort",	"text...\t\tAbort the server",
-	1,	SC_XABORT,	true	},
+	1,	SC_XABORT,	TRUE	},
     { "lowmark",	"filename\t\tReset active file low article marks",
-	1,	SC_LOWMARK,	false	},
+	1,	SC_LOWMARK,	FALSE	},
     { "renumberlow",	"filename\t\tReset active file low article marks",
-	1,	SC_LOWMARK,	false	},
+	1,	SC_LOWMARK,	FALSE	},
     {	"xexec",	"path\t\t\tExec new server",
-	1,	SC_XEXEC,	false	}
+	1,	SC_XEXEC,	FALSE	}
 };
 
-
-static void Usage(const char *) __attribute__ ((__noreturn__));
-static void WrongArgs(COMMAND *) __attribute__ ((__noreturn__));
-
+
 
 /*
 **  Print a help summary.
 */
-static void
-Help(char *p)
+STATIC NORETURN
+Help(p)
+    char		*p;
 {
-    COMMAND	*cp;
+    register COMMAND	*cp;
 
     if (p == NULL) {
-	printf("Command summary:\n");
-	for (cp = Commands; cp < ARRAY_END(Commands); cp++)
-	    printf("  %s %s\n", cp->Command, cp->Text);
-	printf("*   Empty string means all sites/groups/etc.\n");
-	printf("... All trailing words are glued together.\n");
+	(void)printf("Command summary:\n");
+	for (cp = Commands; cp < ENDOF(Commands); cp++)
+	    (void)printf("  %s %s\n", cp->Command, cp->Text);
+	(void)printf("*   Empty string means all sites/groups/etc.\n");
+	(void)printf("... All trailing words are glued together.\n");
 	exit(0);
     }
-    for (cp = Commands; cp < ARRAY_END(Commands); cp++)
-	if (strcmp(p, cp->Command) == 0) {
-	    printf("Command usage:\n");
-	    printf("  %s %s\n", cp->Command, cp->Text);
+    for (cp = Commands; cp < ENDOF(Commands); cp++)
+	if (EQ(p, cp->Command)) {
+	    (void)printf("Command usage:\n");
+	    (void)printf("  %s %s\n", cp->Command, cp->Text);
 	    exit(0);
 	}
-    printf("No such command.\n");
+    (void)printf("No such command.\n");
     exit(0);
 }
 
@@ -146,11 +145,12 @@ Help(char *p)
 /*
 **  Print a command-usage message and exit.
 */
-static void
-WrongArgs(COMMAND *cp)
+STATIC NORETURN
+WrongArgs(cp)
+    COMMAND	*cp;
 {
-    printf("Wrong number of arguments -- usage:\n");
-    printf("  %s %s\n", cp->Command, cp->Text);
+    (void)printf("Wrong number of arguments -- usage:\n");
+    (void)printf("  %s %s\n", cp->Command, cp->Text);
     exit(1);
 }
 
@@ -158,14 +158,16 @@ WrongArgs(COMMAND *cp)
 /*
 **  Print an error message and exit.
 */
-static void
-Failed(const char *p)
+STATIC NORETURN
+Failed(p)
+    char	*p;
 {
     if (ICCfailure)
-        syswarn("cannot %s (%s failure)", p, ICCfailure);
+	(void)fprintf(stderr, "Can't %s (%s failure) %s.\n",
+		p, ICCfailure, strerror(errno));
     else
-        syswarn("cannot %s", p);
-    ICCclose();
+	(void)fprintf(stderr, "Can't %s, %s.\n", p, strerror(errno));
+    (void)ICCclose();
     exit(1);
 }
 
@@ -173,23 +175,24 @@ Failed(const char *p)
 /*
 **  Print an error reporting incorrect usage.
 */
-static void
-Usage(const char *what)
+STATIC NORETURN
+Usage(what)
+    char	*what;
 {
-    fprintf(stderr, "Usage error (%s) -- try -h for help.\n", what);
+    (void)fprintf(stderr, "Usage error (%s) -- try -h for help.\n", what);
     exit(1);
 }
 
 
 int main(int ac, char *av[])
 {
-    static char		Y[] = NF_FLAG_OK_STRING;
+    static char		Y[] = "y";
     static char		EMPTY[] = "";
     COMMAND	        *cp;
     char	        *p;
     int	                i;
-    bool		Silent;
-    bool		NeedHelp;
+    BOOL		Silent;
+    BOOL		NeedHelp;
     char		*reply;
     char		*new;
     int			length;
@@ -197,14 +200,13 @@ int main(int ac, char *av[])
     struct stat		Sb;
     char		buff[SMBUF];
 
-    /* First thing, set up our identity. */
-    message_program_name = "ctlinnd";
+    /* First thing, set up logging and our identity. */
+    openlog("ctlinnd", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);        
 
     /* Set defaults. */
-    if (!innconf_read(NULL))
-        exit(1);
-    Silent = false;
-    NeedHelp = false;
+    if (ReadInnConf() < 0) exit(1);
+    Silent = FALSE;
+    NeedHelp = FALSE;
     ICCsettimeout(CTLINND_TIMEOUT);
 
     /* Parse JCL. */
@@ -214,10 +216,10 @@ int main(int ac, char *av[])
 	    Usage("bad flags");
 	    /* NOTREACHED */
 	case 'h':		/* Get help			*/
-	    NeedHelp = true;
+	    NeedHelp = TRUE;
 	    break;
 	case 's':		/* Silent -- no output		*/
-	    Silent = true;
+	    Silent = TRUE;
 	    break;
 	case 't':		/* Time to wait for reply	*/
 	    ICCsettimeout(atoi(optarg));
@@ -231,12 +233,12 @@ int main(int ac, char *av[])
 	Usage("missing command");
 
     /* Look up the command word and move to the arguments. */
-    if (strcmp(av[0], "help") == 0)
+    if (EQ(av[0], "help"))
 	Help(av[1]);
-    for (cp = Commands; cp < ARRAY_END(Commands); cp++)
-	if (strcmp(av[0], cp->Command) == 0)
+    for (cp = Commands; cp < ENDOF(Commands); cp++)
+	if (EQ(av[0], cp->Command))
 	    break;
-    if (cp == ARRAY_END(Commands))
+    if (cp == ENDOF(Commands))
 	Usage("unknown command");
     ac--;
     av++;
@@ -265,17 +267,16 @@ int main(int ac, char *av[])
 	case 3:
 	    break;
 	}
+	ac = 3;
     }
     else if (ac > cp->argc && cp->Glue) {
 	/* Glue any extra words together. */
 	for (length = 0, i = cp->argc - 1; (p = av[i++]) != NULL; )
 	    length += strlen(p) + 1;
-        new = xmalloc(length);
-        *new = '\0';
-	for (i = cp->argc - 1; av[i]; i++) {
+	for (new = p = NEW(char, length), i = cp->argc - 1; av[i]; i++) {
 	    if (i >= cp->argc)
-                strlcat(new, " ", length);
-            strlcat(new, av[i], length);
+		*p++ = ' ';
+	    p += strlen(strcpy(p, av[i]));
 	}
 	av[cp->argc - 1] = new;
 	av[cp->argc] = NULL;
@@ -291,7 +292,7 @@ int main(int ac, char *av[])
 	    Usage("Bad group mode");
 	    /* NOTREACHED */
 	case NF_FLAG_ALIAS:
-	case NF_FLAG_JUNK:
+	case NF_FLAG_EXCLUDED:
 	case NF_FLAG_MODERATED:
 	case NF_FLAG_OK:
 	case NF_FLAG_NOLOCAL:
@@ -302,34 +303,36 @@ int main(int ac, char *av[])
 
     /* Make sure there are no separators in the parameters. */
     for (i = 0; (p = av[i++]) != NULL; )
-	if (strchr(p, SC_SEP) != NULL)
-            die("illegal character \\%03o in %s", SC_SEP, p);
+	if (strchr(p, SC_SEP) != NULL) {
+	    (void)fprintf(stderr, "Illegal character '\\%03o' in \"%s\"\n",
+		    SC_SEP, p);
+	    exit(1);
+	}
 
     /* Do the real work. */
     if (ICCopen() < 0)
 	Failed("setup communication");
-    i = ICCcommand(cp->Letter, (const char **) av, &reply);
+    i = ICCcommand(cp->Letter, av, &reply);
     if (i < 0) {
 	i = errno;
-	p = concatpath(innconf->pathrun, INN_PATH_SERVERPID);
+	p = cpcatpath(innconf->pathrun, _PATH_SERVERPID);
 	if (stat(p, &Sb) < 0)
-            warn("no innd.pid file; did server die?");
-        free(p);
-	snprintf(buff, sizeof(buff), "send \"%s\" command", cp->Command);
+	    (void)fprintf(stderr, "No innd.pid file; did server die?\n");
+	(void)sprintf(buff, "send \"%s\" command", cp->Command);
 	errno = i;
 	Failed(buff);
     }
 
     if (reply) {
 	/* Skip "<exitcode><space>" part of reply. */
-	for (p = reply; *p && isdigit((unsigned char) *p); p++)
+	for (p = reply; *p && CTYPE(isdigit, *p); p++)
 	    continue;
 	while (*p && ISWHITE(*p))
 	    p++;
 	if (i != 0)
-            warn("%s", p);
+	    (void)fprintf(stderr, "%s\n", p);
 	else if (!Silent)
-	    printf("%s\n", p);
+	    (void)printf("%s\n", p);
     }
 
     if (ICCclose() < 0)
