@@ -1,4 +1,4 @@
-/*  $Id: storage.h,v 1.12.2.1 2000/06/05 22:39:45 kondou Exp $
+/*  $Id: storage.h,v 1.12.2.2 2000/09/05 23:22:24 kondou Exp $
 **
 **  Here be declarations related to the storage subsystem.
 */
@@ -58,7 +58,7 @@ typedef struct {
 extern int              SMerrno;
 extern char             *SMerrorstr;
 
-typedef enum {SELFEXPIRE, SMARTNGNUM} PROBETYPE;
+typedef enum {SELFEXPIRE, SMARTNGNUM, EXPENSIVESTAT} PROBETYPE;
 typedef enum {SM_ALL, SM_HEAD, SM_CANCELEDART} FLUSHTYPE;
 
 struct artngnum {
