@@ -1,13 +1,32 @@
-/*  $Id: configfile.h 7084 2004-12-22 20:33:24Z rra $
-**
-**  Interface to innfeed's configuration file parser.
-**
-**  Written by James Brister <brister@vix.com>
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Fri, 17 Jan 1997 17:35:59 +0100
+ * Project:     INN (innfeed)
+ * File:        configfile.h
+ * RCSId:       $Id: configfile.h,v 1.3 1999/11/25 20:42:28 rra Exp $
+ * Description: 
+ * 
+ */
 
 #if ! defined ( configfile_h__ )
 #define configfile_h__
 
+/* Avoid conflicts with parsedate.y's generated yacc code. */
+#define yy_yyv	innfeed_yy_yyv
+#define yyact	innfeed_yyact
+#define yychk	innfeed_yychk
+#define yydef	innfeed_yydef
+#define yyexca	innfeed_yyexca
+#define yylval	innfeed_yylval
+#define yypact	innfeed_yypact
+#define yypgo	innfeed_yypgo
+#define yyr1	innfeed_yyr1
+#define yyr2	innfeed_yyr2
+#define yys	innfeed_yys
+#define yyv	innfeed_yyv
+#define yyval	innfeed_yyval
+
 /* pointer to function taking void-star param and returning int. */
 typedef int (*PFIVP)(void *) ;
 
@@ -85,7 +104,4 @@ void configCleanup (void) ;
 #define INHERIT 1
 #define NO_INHERIT 0
 
-/* Interface between lexer and parser. */
-int yylex (void) ; 
-
 #endif /* configfile_h__ */
