@@ -1,19 +1,38 @@
-/*  $Id: innfeed.h 9923 2015-07-14 16:48:11Z iulius $
-**
-**  innfeed's configuration values.
-**
-**  Written by James Brister <brister@vix.com>
-**
-**  The application configuration values.  This file is #include'd before any
-**  system header files, so it can't rely on any CPP symbols other that what
-**  the compiler defines.
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Wed Dec 27 08:34:23 1995
+ * Project:     INN (innfeed)
+ * File:        innfeed.h
+ * RCSId:       $Id: innfeed.h,v 1.2 1999/11/21 00:13:19 rra Exp $
+ *
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Description: The application configuration values. This file is #include'd
+ *              before any system header files, so it can't rely on any CPP
+ *              symbols other that what the compiler defines.
+ * 
+ */
 
 #if ! defined ( innfeed_h__ )
 #define innfeed_h__
 
-#include "inn/timer.h"
-
 /**********************************************************************/
 /*                     Application specific defines                   */
 /**********************************************************************/
@@ -24,7 +43,7 @@
 
 
 /*
- * This next section contains things than can be overridden in the config
+ * This next section contains things than can be overriden in the config
  * file. The strings inside each comment is the key used in the
  * innfeed.conf file to override the value here. See innfeed.conf for a
  * description of each./
@@ -45,11 +64,11 @@
 /* in host.c */
 #define DNS_RETRY_PERIOD 	900 		/* dns-retry */
 #define DNS_EXPIRE_PERIOD 	86400 		/* dns-expire */
-#define CLOSE_PERIOD 		(60 * 60 * 24) 	/* close-period */
+#define CLOSE_PERIOD 		(60 * 60) 	/* close-period */
 #define GEN_HTML		false 		/* gen-html */
 #define INNFEED_STATUS 		"innfeed.status" /* status-file */
 #define LOG_CONNECTION_STATS 	0 		/* connection-stats */
-#define HOST_HIGHWATER 		10 		/* host-queue-highwater */
+#define HOST_HIGHWATER 		10 		/* host-highwater */
 #define STATS_PERIOD 		(60 * 10) 	/* stats-period */
 #define STATS_RESET_PERIOD 	(60 * 60 * 12) 	/* stats-reset-period */
 
@@ -57,12 +76,11 @@
 #define RESPTOUT	 	300 		/* response-timeout */
 #define INIT_CXNS		1 		/* initial-connections */
 #define MAX_CXNS		2 		/* max-connections */
-#define MAX_Q_SIZE		20 		/* max-queue-size */
+#define MAX_Q_SIZE		5 		/* max-queue-size */
 #define STREAM			true 		/* streaming */
 #define NOCHECKHIGH 		95.0 		/* no-check-high */
 #define NOCHECKLOW 		90.0 		/* no-check-low */
 #define PORTNUM 		119 		/* port-number */
-#define FORCE_IPv4		false		/* force using IPv4 */
 #define BLOGLIMIT		0 		/* backlog-limit */
 #define LIMIT_FUDGE 		1.10 		/* backlog-factor */
 #define BLOGLIMIT_HIGH		0 		/* backlog-limit-high */
@@ -95,6 +113,12 @@
    a SIGINT is delivered (or SNAPSHOT_ON_DIE is non-zero--see below). */
 #define SNAPSHOT_FILE "innfeed.snapshot" /* Relative to pathlog */
 
+/* Define this be an existing directory (or NULL). If innfeed deliberatly
+   dumps core it will chdir() to this directory first (if non-NULL). If
+   NULL then it will chdir to TAPE_DIRECTORY (as possibly modified by
+   the '-b' option). */
+#define CORE_DIRECTORY NULL
+
 /* strings that get added to the end of a peer name for generating
    backlog file names.  A peername cannot end in any of these string
    (e.g. having a peer called 'mypeer.input' will not work) */
@@ -150,6 +174,34 @@
 #define SELECT_RATIO 3
 
 
+#if ! defined (USE_DMALLOC)
+
+#undef ALLOC
+#define ALLOC(TYPE, COUNT) (TYPE *) malloc(sizeof(TYPE) * (COUNT))
+
+#undef MALLOC
+#define MALLOC(SIZE) (char *) malloc(SIZE)
+
+#undef CALLOC
+#define CALLOC(TYPE, COUNT) (TYPE *) calloc((COUNT), sizeof(TYPE))
+
+#undef REALLOC
+#define REALLOC(ptr, TYPE, COUNT) \
+                  (TYPE *) realloc((char *)(ptr), (sizeof(TYPE) * (COUNT)))
+
+#undef REMALLOC
+#define REMALLOC(ptr, SIZE) (char *) realloc((char *)(ptr),(SIZE))
+
+#undef FREE
+#define FREE(ptr) ((void) (ptr != NULL && (free((char *)(ptr)), ptr = NULL)))
+
+#else
+
+#include <dmalloc.h>
+
+#endif /* !defined (USE_DMALLOC) */
+
+
 #if defined (DBTIMES)
 
   /* some small values for testing things. */
@@ -168,6 +220,15 @@
 
 #endif /* DBTIMES */
 
+#if ! defined (__GNUC__)
+#define __attribute__(x)
+#endif
+  
+#if defined (CHECK_FORMATS)
+extern void syslog (int, const char *,...) __attribute__ ((__format__ (printf, 2, 3)));
+#endif
+
+
 
 /* Additional OS-specific defines.  These should really be moved into
    configure at some point. */
@@ -187,11 +248,23 @@
 # define MAX_STDIO_FD 0
 #endif
 
-/* some timer constants */
+/* If you compiler doesn't support `volatile' then add a line like
+              #define VOLATILE
+   above */
+#if ! defined (VOLATILE)
+#define VOLATILE volatile
+#endif
 
-typedef enum { TMR_IDLE = TMR_APPLICATION, TMR_BACKLOGSTATS,
-  TMR_STATUSFILE, TMR_NEWARTICLE, TMR_READART, TMR_PREPART, TMR_READ,
-  TMR_WRITE, TMR_CALLBACK, TMR_MAX
-} TMRTYPE;
+/* define DONT_NEED_U_INT or DO_NEED_U_INT depending on if you
+   have a `u_long', `u_int', `u_short' in your system include path or not */
+#if ! defined (DO_NEED_U_INT) && ! defined (DONT_NEED_U_INT)
+#define DONT_NEED_U_INT 1
+#endif
+
+/* define DONT_NEED_BOOL or DO_NEED_BOOL depending on if you have a `bool'
+   in your include path or not */
+#if ! defined (DO_NEED_BOOL) && ! defined (DONT_NEED_BOOL)
+#define DO_NEED_BOOL 1
+#endif
 
 #endif /* innfeed_h__ */
