@@ -1,4 +1,4 @@
-/*  $Revision: 1.78.2.14 $
+/*  $Revision: 1.78.2.17 $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **  This server doesn't do any real load-limiting, except for what has
@@ -489,11 +489,11 @@ STATIC void StartConnection()
 	    if (HostErrorStr == NULL) {
 		syslog(L_NOTICE,
 		    "? cant gethostbyaddr %s %m -- using IP address for access",
-		    ClientHost);
+		    ServerHost);
 	    } else {
 		syslog(L_NOTICE,
 		    "? cant gethostbyaddr %s %s -- using IP address for access",
-		    ClientHost, HostErrorStr);
+		    ServerHost, HostErrorStr);
 	    }
 	}
 #else
@@ -513,7 +513,7 @@ STATIC void StartConnection()
 		   NNTP_ACCESS_VAL);
 	    ExitWithStats(1, TRUE);
 	}
-	NGgetlist(&PERMreadlist, accesslist);
+	PERMspecified = NGgetlist(&PERMreadlist, accesslist);
 	PERMpostlist = PERMreadlist;
 	if (!authconf)
 	    authconf = NEW(ACCESSGROUP, 1);
@@ -937,8 +937,8 @@ main(int argc, char *argv[])
 
 	/* Detach */
 	if ((pid = fork()) < 0) {
-	    fprintf(stderr, "%s: can't fork (%s)\n", argv[0], strerror(errno));
-	    syslog(L_FATAL, "can't fork (%m)");
+	    fprintf(stderr, "%s: can't fork: %s\n", argv[0], strerror(errno));
+	    syslog(L_FATAL, "cant fork: %m");
 	    exit(1);
 	} else if (pid != 0) 
 	    exit(0);
@@ -968,11 +968,11 @@ main(int argc, char *argv[])
 	    
 	    for (i = 0; (pid = fork()) < 0; i++) {
 		if (i == MAX_FORKS) {
-		    syslog(L_FATAL, "cant fork %m -- giving up");
-		    exit(1);
+		    syslog(L_FATAL, "cant fork (dropping connection): %m");
+		    continue;
 		}
-		syslog(L_NOTICE, "cant fork %m -- waiting");
-		(void)sleep(1);
+		syslog(L_NOTICE, "cant fork (waiting): %m");
+		sleep(1);
 	    }
 	    if (pid != 0)
 		close(fd);
