@@ -1,4 +1,4 @@
-/*  $Id: perm.c,v 1.17.2.5 2000/06/29 15:56:35 kondou Exp $
+/*  $Id: perm.c,v 1.17.2.7 2001/01/10 16:06:40 kondou Exp $
 **
 **  How to figure out where a user comes from, and what that user can do once
 **  we know who sie is.
@@ -908,15 +908,19 @@ static void PERMreadfile(char *filename)
     int		oldtype;
     char	*str	    = NULL;
 
-    cf		= NEW(CONFCHAIN, 1);
-    cf->f	= CONFfopen(filename);
-    cf->parent	= 0;
-
     if(filename != NULL) {
 	syslog(L_TRACE, "Reading access from %s", 
 	       filename == NULL ? "(NULL)" : filename);
     }
 
+    cf		= NEW(CONFCHAIN, 1);
+    if ((cf->f = CONFfopen(filename)) == NULL) {
+	syslog(L_ERROR, "%s cannot open %s: %m", ClientHost, filename);
+	Reply("%d NNTP server unavailable. Try later.\r\n", NNTP_TEMPERR_VAL);
+	ExitWithStats(1, TRUE);
+    }
+    cf->parent	= 0;
+
     /* are we editing an AUTH or ACCESS group? */
 
     inwhat	= 0;
@@ -1523,7 +1527,7 @@ static void add_authgroup(AUTHGROUP *group)
     } else {
 	for (i = 0; auth_realms[i]; i++)
 	    ;
-	auth_realms = RENEW(auth_realms, AUTHGROUP*, i+2);
+	RENEW(auth_realms, AUTHGROUP*, i+2);
     }
     auth_realms[i] = group;
     auth_realms[i+1] = 0;
@@ -1539,7 +1543,7 @@ static void add_accessgroup(ACCESSGROUP *group)
     } else {
 	for (i = 0; access_realms[i]; i++)
 	    ;
-	access_realms = RENEW(access_realms, ACCESSGROUP*, i+2);
+	RENEW(access_realms, ACCESSGROUP*, i+2);
     }
     access_realms[i] = group;
     access_realms[i+1] = 0;
@@ -1665,7 +1669,8 @@ static void GetConnInfo(METHOD *method, char *buf)
 {
     struct sockaddr_in cli, loc;
     int gotsin;
-    int i, j;
+    int i;
+    ARGTYPE j;
 
     j = sizeof(cli);
     gotsin = (getpeername(0, (struct sockaddr*)&cli, &j) == 0);
