@@ -1,4 +1,4 @@
-#! /bin/sh
+#! /bin/sh 
 ##  $Revision: 1.4 $
 ##
 ##  Safely get a file from the samples directory.  Usage:
@@ -31,6 +31,11 @@ fi
 
 ##  File exist locally?
 if [ -f ${DEST} ] ; then
+    cmp ${SRC} ${DEST}
+    if [ $? -eq 0 ] ; then
+	touch ${DEST}
+	exit 0
+    fi
     echo "${SRC} has changed; please update ${DEST}"
     exit 1
 fi
@@ -38,14 +43,4 @@ fi
 echo Using sample version of ${DEST}
 cp ${SRC} ${DEST}
 
-##  See if we should put the file under RCS control.
-if [ -d RCS -a ! -d SCCS ] ; then
-    echo INN config file | ci -u -q ${DEST}
-fi
-
-##  See if we should put the file under SCCS control.
-if [ -d SCCS -a ! -d RCS ] ; then
-    sccs create ${DEST} >/dev/null && rm -f ,${DEST}
-fi
-
 exit 0
