@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c,v 1.40.2.2 2000/08/09 10:58:42 kondou Exp $
+/*  $Id: buffindexed.c,v 1.40.2.4 2000/11/10 01:57:28 kondou Exp $
 **
 **  Overview buffer and index method.
 */
@@ -562,8 +562,7 @@ STATIC BOOL ovbuffinit_disks(void) {
 	if (strncmp(rpx->path, ovbuff->path, OVBUFFPASIZ) != 0) {
 	  syslog(L_ERROR, "%s: Path mismatch: read %s for buffindexed %s",
 		   LocalLogName, rpx->path, ovbuff->path);
-	  ovlock(ovbuff, LOCK_UNLOCK);
-	  return FALSE;
+	  ovbuff->needflush = TRUE;
 	}
 	strncpy(buf, rpx->indexa, OVBUFFLASIZ);
 	buf[OVBUFFLASIZ] = '\0';
@@ -592,6 +591,7 @@ STATIC BOOL ovbuffinit_disks(void) {
 	strncpy(buf, rpx->freea, OVBUFFLASIZ);
 	buf[OVBUFFLASIZ] = '\0';
 	ovbuff->freeblk = hex2offt(buf);
+	ovflushhead(ovbuff);
 	Needunlink = FALSE;
     } else {
 	ovbuff->totalblk = (ovbuff->len - ovbuff->base)/OV_BLOCKSIZE;
@@ -1840,15 +1840,14 @@ BOOL buffindexed_expiregroup(char *group, int *lo) {
     ah = NULL;
     if (len == 0)
       continue; 
-    if (SMprobe(SELFEXPIRE, &token, NULL)) {
+    if (!SMprobe(EXPENSIVESTAT, &token, NULL) || OVstatall) {
       if ((ah = SMretrieve(token, RETR_STAT)) == NULL)
         continue; 
+      SMfreearticle(ah);
     } else {
-      if (!innconf->groupbaseexpiry && !OVhisthasmsgid(data))
+      if (!OVhisthasmsgid(data))
 	continue; 
     }
-    if (ah)
-      SMfreearticle(ah);
     if (innconf->groupbaseexpiry && OVgroupbasedexpire(token, group, data, len, arrived, expires))
       continue;
 #ifdef OV_DEBUG
