@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c,v 1.73.2.1 2000/06/09 00:10:22 rra Exp $
+/*  $Id: cnfs.c,v 1.73.2.3 2000/12/21 22:18:02 kondou Exp $
 **
 **  Cyclic News File System.
 */
@@ -984,12 +984,18 @@ STATIC void CNFSshutdowncycbuff(CYCBUFF *cycbuff) {
     cycbuff->fd = -1;
 }
 
-BOOL cnfs_init(BOOL *selfexpire) {
+BOOL cnfs_init(SMATTRIBUTE *attr) {
     int			ret;
     METACYCBUFF	*metacycbuff;
     CYCBUFF	*cycbuff;
 
-    *selfexpire = FALSE;
+    if (attr == NULL) {
+	syslog(L_ERROR, "%s: attr is NULL", LocalLogName);
+	SMseterror(SMERR_INTERNAL, "attr is NULL");
+	return FALSE;
+    }
+    attr->selfexpire = TRUE;
+    attr->expensivestat = FALSE;
     if (innconf == NULL) {
 	if ((ret = ReadInnConf()) < 0) {
 	    syslog(L_ERROR, "%s: ReadInnConf failed, returned %d", LocalLogName, ret);
@@ -1053,8 +1059,6 @@ BOOL cnfs_init(BOOL *selfexpire) {
 	CNFSshutdowncycbuff(cycbuff);
       }
     }
-
-    *selfexpire = TRUE;
     return TRUE;
 }
 
@@ -1309,7 +1313,8 @@ ARTHANDLE *cnfs_retrieve(const TOKEN token, const RETRTYPE amount) {
 	}
     }
     /* checking the bitmap to ensure cah.size is not broken was dropped */
-    if ((innconf->cnfscheckfudgesize != 0) && (ntohl(cah.size) > innconf->maxartsize + innconf->cnfscheckfudgesize)) {
+    if (innconf->cnfscheckfudgesize != 0 && innconf->maxartsize != 0 &&
+	(ntohl(cah.size) > innconf->maxartsize + innconf->cnfscheckfudgesize)) {
 	char buf1[24], buf2[24], buf3[24];
 	strcpy(buf1, CNFSofft2hex(cycbuff->free, FALSE));
 	strcpy(buf2, CNFSofft2hex(middle, FALSE));
