@@ -1,4 +1,4 @@
-/*  $Id: cnfs.h,v 1.6 1999/09/13 05:55:04 kondou Exp $
+/*  $Id: cnfs.h,v 1.6.2.1 2000/09/05 23:23:05 kondou Exp $
 **
 **  cyclic news file system header
 */
@@ -6,7 +6,7 @@
 #ifndef __CNFS_H__
 #define __CNFS_H__
 
-BOOL cnfs_init(BOOL *selfexpire);
+BOOL cnfs_init(SMATTRIBUTE *attr);
 TOKEN cnfs_store(const ARTHANDLE article, const STORAGECLASS class);
 ARTHANDLE *cnfs_retrieve(const TOKEN token, const RETRTYPE amount);
 ARTHANDLE *cnfs_next(const ARTHANDLE *article, const RETRTYPE amount);
