@@ -1,4 +1,4 @@
-/*  $Id: interface.h,v 1.15 1999/09/13 05:54:31 kondou Exp $
+/*  $Id: interface.h,v 1.15.2.1 2000/09/05 23:24:23 kondou Exp $
 **
 **  Storage Manager interface header
 */
@@ -9,10 +9,15 @@
 #include <configdata.h>
 #include <storage.h>
 
+typedef struct {
+    BOOL	selfexpire;
+    BOOL	expensivestat;
+} SMATTRIBUTE;
+
 typedef struct {
     char                *name;
     unsigned char       type;
-    BOOL                (*init)(BOOL *type);
+    BOOL                (*init)(SMATTRIBUTE *attr);
     TOKEN               (*store)(const ARTHANDLE article, const STORAGECLASS storageclass);
     ARTHANDLE           *(*retrieve)(const TOKEN token, const RETRTYPE amount);
     ARTHANDLE           *(*next)(const ARTHANDLE *article, const RETRTYPE amount);
