@@ -1,4 +1,4 @@
-/*  $Id: timecaf.c,v 1.10 1999/11/28 23:32:12 rra Exp $
+/*  $Id: timecaf.c,v 1.10.2.2 2000/09/16 17:11:49 kondou Exp $
 **
 **  Like the timehash storage method (and heavily inspired by it), but uses
 **  the CAF library to store multiple articles in a single file.
@@ -160,8 +160,14 @@ static TOKEN *PathNumToToken(char *path, ARTNUM artnum) {
 }
 
 
-BOOL timecaf_init(BOOL *selfexpire) {
-    *selfexpire = FALSE;
+BOOL timecaf_init(SMATTRIBUTE *attr) {
+    if (attr == NULL) {
+	syslog(L_ERROR, "timecaf: attr is NULL");
+	SMseterror(SMERR_INTERNAL, "attr is NULL");
+	return FALSE;
+    }
+    attr->selfexpire = FALSE;
+    attr->expensivestat = FALSE;
     if (STORAGE_TOKEN_LENGTH < 6) {
 	syslog(L_FATAL, "timecaf: token length is less than 6 bytes");
 	SMseterror(SMERR_TOKENSHORT, NULL);
@@ -408,6 +414,20 @@ static ARTHANDLE *OpenArticle(const char *path, ARTNUM artnum, const RETRTYPE am
     char                *p;
     SIZE_T		len;
     ARTHANDLE           *art;
+    static long		pagesize = 0;
+
+    if (pagesize == 0) {
+#if     defined(HAVE_GETPAGESIZE)
+	pagesize = getpagesize();
+#elif   defined(_SC_PAGESIZE)
+	if ((pagesize = sysconf(_SC_PAGESIZE)) < 0) {
+	    syslog(L_ERROR, "timecaf sysconf(_SC_PAGESIZE) failed: %m");
+	    return NULL;
+	}
+#else
+	pagesize = 16384;
+#endif
+   }
 /* XXX need to figure some way to cache open fds or something? */
     if ((fd = CAFOpenArtRead((char *)path, artnum, &len)) < 0) {
         if (caf_error == CAF_ERR_ARTNOTHERE) {
@@ -437,7 +457,7 @@ static ARTHANDLE *OpenArticle(const char *path, ARTNUM artnum, const RETRTYPE am
 	size_t delta;
 
 	curoff = lseek(fd, (off_t) 0, SEEK_CUR);
-	delta = curoff % getpagesize();
+	delta = curoff % pagesize;
 	tmpoff = curoff - delta;
 	private->mmaplen = len + delta;
 	if ((private->mmapbase = mmap((MMAP_PTR)0, private->mmaplen, PROT_READ, MAP__ARG, fd, tmpoff)) == (MMAP_PTR)-1) {
