@@ -1,5 +1,5 @@
 /*
-** $Id: timecaf.h,v 1.3 1999/09/13 05:55:20 kondou Exp $
+** $Id: timecaf.h,v 1.3.2.1 2000/09/05 23:24:57 kondou Exp $
 ** timecaf -- like the timehash storage method (and heavily inspired
 ** by it), but uses the CAF library to store multiple articles in a
 ** single file. 
@@ -11,7 +11,7 @@
 #include <configdata.h>
 #include <interface.h>
 
-BOOL timecaf_init(BOOL *selfexpire);
+BOOL timecaf_init(SMATTRIBUTE *attr);
 TOKEN timecaf_store(const ARTHANDLE article, const STORAGECLASS class);
 ARTHANDLE *timecaf_retrieve(const TOKEN token, const RETRTYPE amount);
 ARTHANDLE *timecaf_next(const ARTHANDLE *article, const RETRTYPE amount);
