@@ -1,4 +1,4 @@
-/*  $Id: timehash.h,v 1.8 1999/09/13 05:55:38 kondou Exp $
+/*  $Id: timehash.h,v 1.8.2.1 2000/09/05 23:25:04 kondou Exp $
 **
 **  timehash based storing method header
 */
@@ -9,7 +9,7 @@
 #include <configdata.h>
 #include <interface.h>
 
-BOOL timehash_init(BOOL *selfexpire);
+BOOL timehash_init(SMATTRIBUTE *attr);
 TOKEN timehash_store(const ARTHANDLE article, const STORAGECLASS class);
 ARTHANDLE *timehash_retrieve(const TOKEN token, const RETRTYPE amount);
 ARTHANDLE *timehash_next(const ARTHANDLE *article, const RETRTYPE amount);
