@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c,v 1.23.2.1 2000/04/27 08:46:27 rra Exp $
+/*  $Id: tradspool.c,v 1.23.2.2 2000/09/05 23:25:12 kondou Exp $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -436,8 +436,14 @@ CheckNeedReloadDB(void) {
 /* Init routine, called by SMinit */
 
 BOOL
-tradspool_init(BOOL *selfexpire) {
-    *selfexpire = FALSE;
+tradspool_init(SMATTRIBUTE *attr) {
+    if (attr == NULL) {
+	syslog(L_ERROR, "tradspool: attr is NULL");
+	SMseterror(SMERR_INTERNAL, "attr is NULL");
+	return FALSE;
+    }
+    attr->selfexpire = FALSE;
+    attr->expensivestat = TRUE;
     return InitNGTable();
 }
 
