@@ -1,5 +1,5 @@
 /*
-** $Id: tradspool.h,v 1.3 1999/09/13 05:55:57 kondou Exp $
+** $Id: tradspool.h,v 1.3.2.1 2000/09/05 23:25:13 kondou Exp $
 ** tradspool -- storage manager for traditional spool format.
 */
 
@@ -9,7 +9,7 @@
 #include <configdata.h>
 #include <interface.h>
 
-BOOL tradspool_init(BOOL *selfexpire);
+BOOL tradspool_init(SMATTRIBUTE *attr);
 TOKEN tradspool_store(const ARTHANDLE article, const STORAGECLASS class);
 ARTHANDLE *tradspool_retrieve(const TOKEN token, const RETRTYPE amount);
 ARTHANDLE *tradspool_next(const ARTHANDLE *article, const RETRTYPE amount);
