@@ -1,4 +1,4 @@
-/*  $Id: trash.c,v 1.10 2000/04/08 04:29:14 rra Exp $
+/*  $Id: trash.c,v 1.10.2.1 2000/09/05 23:25:26 kondou Exp $
 **
 **  Trashing articles method
 */
@@ -7,8 +7,13 @@
 #include "libinn.h"
 #include "methods.h"
 
-BOOL trash_init(BOOL *selfexpire) {
-    *selfexpire = TRUE;
+BOOL trash_init(SMATTRIBUTE *attr) {
+    if (attr == NULL) {
+	SMseterror(SMERR_INTERNAL, "attr is NULL");
+	return FALSE;
+    }
+    attr->selfexpire = TRUE;
+    attr->expensivestat = FALSE;
     return TRUE;
 }
 
