@@ -1,4 +1,4 @@
-/*  $Id: trash.h,v 1.5 1999/09/13 05:56:18 kondou Exp $
+/*  $Id: trash.h,v 1.5.2.1 2000/09/05 23:25:27 kondou Exp $
 **
 **  trashing articles method header
 */
@@ -9,7 +9,7 @@
 #include <configdata.h>
 #include <interface.h>
 
-BOOL trash_init(BOOL *selfexpire);
+BOOL trash_init(SMATTRIBUTE *attr);
 TOKEN trash_store(const ARTHANDLE article, const STORAGECLASS class);
 ARTHANDLE *trash_retrieve(const TOKEN token, const RETRTYPE amount);
 ARTHANDLE *trash_next(const ARTHANDLE *article, const RETRTYPE amount);
